@@ -180,9 +180,9 @@
 #define ATTR_reported    "reported"
 #define ATTR_intcmd      "inter_cmd"
 
-#ifdef ENABLE_CSA
+#ifdef USEJOBCREATE
 #define ATTR_pagg         "pagg_id"
-#endif /* ENABLE_CSA */
+#endif /* USEJOBCREATE */
 
 /* additional queue attributes names */
 
@@ -239,6 +239,8 @@
 #define ATTR_aclroot     "acl_roots"
 #define ATTR_managers    "managers"
 #define ATTR_dfltque     "default_queue"
+#define ATTR_dispsvrsuffix "display_job_server_suffix"
+#define ATTR_jobsuffixalias "job_suffix_alias"
 #define ATTR_defnode     "default_node"
 #define ATTR_locsvrs     "location_servers"
 #define ATTR_logevents   "log_events"
@@ -564,6 +566,9 @@ extern char **
 extern int
   pbs_sigjob A_((int connect, char *job_id, char *signal, char *extend));
 
+extern int
+  pbs_sigjobasync A_((int connect, char *job_id, char *signal, char *extend));
+
 extern void
   pbs_statfree A_((struct batch_status *stat));
 
