@@ -920,7 +920,7 @@ attribute_def job_attr_def[] =
     PARENT_TYPE_JOB
   },
 
-#ifdef ENABLE_CSA
+#ifdef USEJOBCREATE
   /* JOB_ATR_pagg_id */
   { ATTR_pagg,  /* "pagg_id" */
     decode_ll,
@@ -933,7 +933,7 @@ attribute_def job_attr_def[] =
     ATR_TYPE_LL,
     PARENT_TYPE_JOB
   },
-#endif /* ENABLE_CSA */
+#endif /* USEJOBCREATE */
 
   /* Site defined attributes if any, see site_job_attr_*.h  */
 #include "site_job_attr_def.h"
