@@ -91,6 +91,7 @@
 #include <stdlib.h>
 #include "libpbs.h"
 #include <ctype.h>
+#include <stdio.h>
 #include "server_limits.h"
 #include "list_link.h"
 #include "attribute.h"
@@ -102,6 +103,7 @@
 #include "work_task.h"
 #include "pbs_error.h"
 #include "svrfunc.h"
+#include "resource.h"
 
 
 extern int     svr_authorize_jobreq A_((struct batch_request *, job *));
@@ -113,7 +115,7 @@ extern attribute_def job_attr_def[];
 extern int      resc_access_perm; /* see encode_resc() in attr_fn_resc.c */
 
 extern struct server server;
-
+extern time_t time_now;
 
 
 
@@ -284,6 +286,63 @@ int status_attrib(
           (padef + index)->at_name,
           NULL,
           ATR_ENCODE_CLIENT);
+
+        /* add walltime remaining if started */
+        if (index == JOB_ATR_start_time)
+          {
+          /* encode walltime remaining, this is custom because walltime 
+           * remaining isn't an attribute */
+          int       len;
+          char      buf[MAXPATHLEN];
+          char     *pname;
+          svrattrl *pal;
+          resource *pres;
+
+          int found = 0;
+          unsigned long remaining;
+
+          if ((pattr + JOB_ATR_resource)->at_flags & ATR_VFLAG_SET)
+            {
+            pres = (resource *)GET_NEXT((pattr + JOB_ATR_resource)->at_val.at_list);
+            
+            /* find the walltime resource */
+            for (;pres != NULL;pres = (resource *)GET_NEXT(pres->rs_link))
+              {
+              pname = pres->rs_defin->rs_name;
+              
+              if (strcmp(pname, "walltime") == 0)
+                {
+                /* found walltime */
+                unsigned long value = (unsigned long)pres->rs_value.at_val.at_long;
+                if (((pattr+index)->at_flags & ATR_VFLAG_SET) != FALSE)
+                  {
+                  remaining = value - (time_now - (pattr + index)->at_val.at_long);
+                  }
+                else
+                  {
+                  remaining = value;
+                  }
+                found = TRUE;
+                break;
+                }
+              }
+            }
+         
+          if (found == TRUE)
+            {
+            snprintf(buf,sizeof(buf),"%ld",remaining);
+
+            len = strlen(buf+1);
+            pal = attrlist_create("Walltime","Remaining",len);
+
+            if (pal != NULL)
+              {
+              memcpy(pal->al_value,buf,len);
+              pal->al_flags = ATR_VFLAG_SET;
+              append_link(phead,&pal->al_link,pal);
+              }
+            }
+          } /* END if (index == JOB_ATR_start_time) */
         }
       }
     }    /* END for (index) */
